==> percona-server-5.6_5.6.50-90.0.orig.tar.gz: percona-server-5.6.50-90.0/storage/ndb/src/kernel/blocks/dbacc/DbaccProxy.hpp <==
/* Copyright (C) 2008 MySQL AB, 2009 Sun Microsystems, Inc.
    All rights reserved. Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA */

#ifndef NDB_DBACC_PROXY_HPP
#define NDB_DBACC_PROXY_HPP

#include <LocalProxy.hpp>
#include <signaldata/DropTab.hpp>

class DbaccProxy : public LocalProxy {
public:
  DbaccProxy(Block_context& ctx);
  virtual ~DbaccProxy();
  BLOCK_DEFINES(DbaccProxy);

protected:
  virtual SimulatedBlock* newWorker(Uint32 instanceNo);
};

#endif

==> percona-server-8.0.15-6.tar.gz: percona-server-8.0.15-6/storage/ndb/src/kernel/blocks/dbacc/DbaccProxy.hpp <==
/* Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef NDB_DBACC_PROXY_HPP
#define NDB_DBACC_PROXY_HPP

#include <LocalProxy.hpp>
#include <signaldata/DropTab.hpp>

#define JAM_FILE_ID 343


class DbaccProxy : public LocalProxy {
public:
  DbaccProxy(Block_context& ctx);
  virtual ~DbaccProxy();
  BLOCK_DEFINES(DbaccProxy);

protected:
  virtual SimulatedBlock* newWorker(Uint32 instanceNo);
};


#undef JAM_FILE_ID

#endif
